.. _vmware_ansible:

******************
VMware Guide
******************

Welcome to the Ansible for VMware Guide!

The purpose of this guide is to teach you everything you need to know about using Ansible with VMware.

To get started, please select one of the following topics.

.. toctree::
   :maxdepth: 1

   vmware_scenarios/vmware_intro
   vmware_scenarios/vmware_concepts
   vmware_scenarios/vmware_requirements
   vmware_scenarios/vmware_inventory
   vmware_scenarios/vmware_inventory_vm_attributes
   vmware_scenarios/vmware_inventory_hostnames
   vmware_scenarios/vmware_inventory_filters
   vmware_scenarios/vmware_scenarios
   vmware_scenarios/vmware_troubleshooting
   vmware_scenarios/vmware_external_doc_links
   vmware_scenarios/faq
.. comments look like this - start with two dots
.. getting_started content not ready
.. vmware_scenarios/vmware_getting_started
.. module index page not ready
.. vmware_scenarios/vmware_module_reference
.. always exclude the template file
.. vmware_scenarios/vmware_scenario_1
